==> messagelib-20.03.80.tar.xz: messagelib-20.03.80/messagecore/src/attachment/attachmentcompressjob.h <==
/*
  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef MESSAGECORE_ATTACHMENTCOMPRESSJOB_H
#define MESSAGECORE_ATTACHMENTCOMPRESSJOB_H

#include "messagecore_export.h"

#include "attachmentpart.h"

#include <KJob>

namespace MessageCore {
/**
 * @short A job to compress the attachment of an email.
 *
 * @author Constantin Berzan <exit3219@gmail.com>
 */
class MESSAGECORE_EXPORT AttachmentCompressJob : public KJob
{
    Q_OBJECT

public:
    /**
     * Creates a new attachment compress job.
     *
     * @param part The part of the attachment to compress.
     * @param parent The parent object.
     */
    explicit AttachmentCompressJob(const AttachmentPart::Ptr &part, QObject *parent = nullptr);

    /**
     * Destroys the attachment compress job.
     */
    ~AttachmentCompressJob() override;

    /**
     * Starts the attachment compress job.
     */
    void start() override;

    /**
     * Sets the original @p part of the compressed attachment.
     */
    void setOriginalPart(const AttachmentPart::Ptr &part);

    /**
     * Returns the original part of the compressed attachment.
     */
    Q_REQUIRED_RESULT const AttachmentPart::Ptr originalPart() const;

    /**
     * Returns the compressed part of the attachment.
     *
     * @note does not delete it unless it failed...
     */
    Q_REQUIRED_RESULT AttachmentPart::Ptr compressedPart() const;

    /**
     * Returns whether the compressed part is larger than the original part.
     */
    Q_REQUIRED_RESULT bool isCompressedPartLarger() const;

private:
    //@cond PRIVATE
    class Private;
    Private *const d;
    //@endcond
};
}

#endif

==> messagelib-21.07.90.tar.xz: messagelib-21.07.90/messagecore/src/attachment/attachmentcompressjob.h <==
/*
  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>

  SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include "messagecore_export.h"

#include "attachmentpart.h"

#include <KJob>

namespace MessageCore
{
/**
 * @short A job to compress the attachment of an email.
 *
 * @author Constantin Berzan <exit3219@gmail.com>
 */
class MESSAGECORE_EXPORT AttachmentCompressJob : public KJob
{
    Q_OBJECT

public:
    /**
     * Creates a new attachment compress job.
     *
     * @param part The part of the attachment to compress.
     * @param parent The parent object.
     */
    explicit AttachmentCompressJob(const AttachmentPart::Ptr &part, QObject *parent = nullptr);

    /**
     * Destroys the attachment compress job.
     */
    ~AttachmentCompressJob() override;

    /**
     * Starts the attachment compress job.
     */
    void start() override;

    /**
     * Sets the original @p part of the compressed attachment.
     */
    void setOriginalPart(const AttachmentPart::Ptr &part);

    /**
     * Returns the original part of the compressed attachment.
     */
    Q_REQUIRED_RESULT const AttachmentPart::Ptr originalPart() const;

    /**
     * Returns the compressed part of the attachment.
     *
     * @note does not delete it unless it failed...
     */
    Q_REQUIRED_RESULT AttachmentPart::Ptr compressedPart() const;

    /**
     * Returns whether the compressed part is larger than the original part.
     */
    Q_REQUIRED_RESULT bool isCompressedPartLarger() const;

private:
    //@cond PRIVATE
    class Private;
    Private *const d;
    //@endcond
};
}
